#!/bin/bash

# This script runs the XSLT on each filename provided on the command
# line.  The output is written to the directory, "$1", and the list of
# files to process are "$2" "$3" ... "$n" for however many files there
# are...

XSL=${XSL:-_exemplar.xsl}
ECHO="echo -n"
DOCTYPE='<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN" "http://www.w3.org/TR/REC-html40/loose.dtd">'

shopt -s extglob	# Enables wildcard patterns:  @(), !(), ?(), *(), +()
set -e			# Exit on error condition
PARAM=$1
shift

case "$PARAM" in
    *macro)
	echo "Running transform to convert HTML files into frame()'s with CSS."
	echo "Output being stored in '$PARAM/*.mtm'"
	[[ ! -d "$PARAM" ]] && mkdir "$PARAM"
	;;
    *html)
	echo "Running transform to convert HTML files into cleaned up HTML."
	echo "Output being stored in '$PARAM/*.html'"
	[[ ! -d "$PARAM" ]] && mkdir "$PARAM"
	;;
    *)
	echo "$0: Invalid parameter -- must match '*macro' or '*html'."
	exit 2
	;;
esac

$ECHO "$0: Starting processing .."
for file
do
    if [[ "$file" != *.@(htm|html) ]]; then
	echo "$0: Skipping invalid filename -- must be '*.htm' or '*.html'."
    fi
    BASE=${file##*/}
    case "$PARAM" in
    *macro)
	# Unfortunately, brackets ("[]") are handled as macro commands
	# by MapTool.  So before doing anything else, I convert all
	# brackets into their corresponding HTML entity codes.  That way
	# I know that all brackets in the resulting output (ie. macro)
	# is there because *I* put it there. ;)
	$ECHO "."
	(
	perl mb2ascii.pl "$file" |
	    sed -e 's/\[/\&amp;#x5B;/g' \
		-e 's/\]/\&amp;#x5D;/g' |
	    xsltproc --html "$XSL" - |
	    sed -e 's/_CSS_LINK/_CSS@[r: getMacroLocation()]/g' \
		-e 's/_MAGIC_LINK/_MAGIC@[r: getMacroLocation()]/g' \
		-e '/<link rel=/{;s#/>#>#;}' \
		-e '/<br clear=/{;s#/>#>#;}' |
	    perl -n -e 's/\s+$//;' -e 'print "$_\n" unless /^$/;'
	) > "$PARAM/${BASE%.@(htm|html)}.mtm"
	;;
    *html)
	$ECHO "."
	(
	echo "$DOCTYPE"
	perl mb2ascii.pl "$file" |
	    xsltproc --html "$XSL" - |
	    perl -n -e 's/\s+$//;' -e 'print "$_\n" unless /^$/;'
	) > "$PARAM/${BASE%.@(htm|html)}.html"
	;;
    esac
done
echo		# Terminates the long lines of dots...
