<?xml version="1.0"?>
<!-- vi:set sw=2: -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output omit-xml-declaration="yes" indent="no" />
  <xsl:param name="inputFile">-</xsl:param>
  <xsl:variable name="css">_CSS_LINK</xsl:variable>
  <xsl:variable name="magic">_MAGIC_LINK</xsl:variable>
  <xsl:variable name="spellName">
    <xsl:value-of select="/html/body/h1[1]" />
  </xsl:variable>
  <xsl:variable name="statBlock" select="//table[@class='statBlock']" />

  <xsl:template match="/">
    <xsl:text disable-output-escaping="yes">[frame("Spell"): {
[h: arguments = arg(0) ]
[h: t_Type = json.get(arguments, "Type")]
[h: t_CasterLevel = json.get(arguments, "CasterLevel")]
[h: t_SpellLevel = json.get(arguments, "SpellLevel")]
[h, if(t_Type == ""): t_Type = "Spell" ]
[h, if(t_CasterLevel == ""): t_CasterLevel = 0 ]
[h, if(t_SpellLevel == ""): t_SpellLevel = 0 ]
[h: t_loc = getMacroLocation()]
[h: t_macro = "_" + t_Type + "@" + t_loc]
[h: t_msg = '(Click for ' + t_Type + ' rules summary)' ]
    </xsl:text>
    <html>
      <head>
    <xsl:text>&#x0A;</xsl:text>
	<title>Spell: <xsl:value-of select="//h1[1]" /></title>
    <xsl:text>&#x0A;</xsl:text>
	<link rel="stylesheet" type="text/css" href="{$css}" />
    <xsl:text>&#x0A;</xsl:text>
      </head>
      <body>
    <xsl:text>&#x0A;</xsl:text>
      <h1><xsl:value-of select="$spellName" /> <small>
	[r: macroLink(t_msg, t_macro, 'none', arguments, currentToken()) ]
      </small></h1>
    <xsl:text>&#x0A;</xsl:text>
	<div class="floatLeft">
	  <h3><xsl:value-of select="/html/body/h4[1]" /></h3>
	  <xsl:apply-templates select="$statBlock" />
	</div>
	<xsl:call-template name="summaryBlock" />
    <xsl:text>&#x0A;</xsl:text>
	<br clear="all"></br>
    <xsl:text>&#x0A;</xsl:text>
	<xsl:apply-templates select="$statBlock/following-sibling::*" />
    <xsl:text>&#x0A;</xsl:text>
	<xsl:apply-templates select="/html/body/h4[1]/h6" />
    <xsl:text>&#x0A;</xsl:text>
      </body>
    </html>
    <xsl:text disable-output-escaping="yes">
      } ]</xsl:text>
  </xsl:template>

  <xsl:template match="div[@id='header']|div[@id='dc15search']" />
  <xsl:template match="div[@class='footer']" />

  <xsl:template match="table[@class='statBlock']">
    <table class="statBlock" cellspacing="0">
      <xsl:apply-templates />
    </table>
  </xsl:template>
  <xsl:template match="table[@class='statBlock']//td" />
  <xsl:template match="table[@class='statBlock']//th" >
    <th>
      <xsl:apply-templates />
    </th>
    <td>
      <xsl:apply-templates mode="m" select="following-sibling::td" />
      <xsl:if test="contains(., 'Saving Throw')">
	<xsl:text disable-output-escaping="yes">
	  (DC [r: dnd.calcDC(arguments) ])
	</xsl:text>
      </xsl:if>
    </td>
  </xsl:template>

  <xsl:template match="div|p|tbody|tr|th|td">
    <xsl:copy>
      <xsl:apply-templates select="@*" />
      <xsl:apply-templates />
    </xsl:copy>
  </xsl:template>

  <!-- <xsl:template match="table[@class!='statBlock']"> -->
  <xsl:template match="table">
    <table class="inset" cellspacing="0" border="1">
      <!-- <xsl:copy-of select="child::*" /> -->
      <xsl:apply-templates />
    </table>
  </xsl:template>

  <xsl:template match="h6">
    <h3>
      <xsl:apply-templates select="@*" />
      <xsl:apply-templates />
    </h3>
  </xsl:template>

  <xsl:template match="@*">
    <xsl:copy>
    </xsl:copy>
  </xsl:template>

  <xsl:template match="a">
    <span class="link">
      <xsl:apply-templates />
    </span>
  </xsl:template>

  <xsl:template match="a[@class='spell']">
    <xsl:variable name="macro">
      <xsl:value-of select="concat('_SPELL_NAME(',@href,')')" />
    </xsl:variable>
    <a class="spell" href="[r: macroLinkText('{$macro}', 'none', arguments, currentToken())]">
      <xsl:apply-templates />
    </a>
  </xsl:template>

  <xsl:template match="a[@class='diceRoller']">
<!--
<a href="javascript:void(0);" class="diceRoller" onclick="rollValue('Total','1d6');" title="Roll the dice!">1d6</a>
-->
    <xsl:variable name="macro">
      <xsl:value-of select="'_diceBox@this'" />
    </xsl:variable>
    <xsl:variable name="args">
      <xsl:value-of select="text()" />
    </xsl:variable>
    <a class="diceRoller" href="[r: macroLinkText('{$macro}', 'none', '{$args}', currentToken())]">
      <xsl:apply-templates />
    </a>
  </xsl:template>

  <xsl:template name="summaryBlock">
  </xsl:template>

</xsl:stylesheet>
