#!/usr/bin/perl -w

# This script reads a bunch of Java text that uses the '\u' notation or
# multi-byte UTF-8 and converts them to regular ASCII text using a
# conversion table.

use Getopt::Long;

my $newlines = 0;	# Preserve newlines?  Otherwise converted into spaces
my $paragraphs = 0;	# Operate on paragraphs at a time?
my $result = GetOptions("n" => \$newlines);
die unless $result;

my $UNICODE = '\\u';
my %unicode = (
    'B0' => '&deg;',
    'BD' => '&frac12;',
    'D7' => '&times;',
    '2014' => ' -- ',
    '2019' => "&amp;apos;",
    '201C' => '<span class="term">',
    '201D' => '</span>',
);

# $^I = ".bak";		# Turn on in-place editing of files
$/ = "" if $paragraphs;	# Two \n's in a row is the input record separator

my %bytes = ();
$bytes{ "\x93" } = "-";		# These are all prefixed with '\xE2\x80'
$bytes{ "\x94" } = " -- ";
$bytes{ "\x99" } = "&amp;apos;";
$bytes{ "\x9c" } = "\"";
$bytes{ "\x9d" } = "\"";
my $keys = join('|', keys(%bytes));
my $multibyte = join('|', map { sprintf('%X', ord($_)) } keys(%bytes) );

while (<>) {
    s/\xE2\x80($keys)/$bytes{$1}/g;
    s/\Q$UNICODE\E(....)/$unicode{$1}/g;
    if (/&#x/) {
	s/&#xE2;&#x80;&#x($multibyte);/$bytes{chr(hex($1))}/ig;
	s/&#x([0-9a-f]{4}|[0-9a-f]{2});/$unicode{$1}/ig;
    }
    if (!$newlines) {	# If not preserving newlines, replace them with spaces.
	s/[\r\n]+/ /g;
    }
    s/\s+$//g;
} continue {
    print $_, (eof(ARGV) or !$paragraphs ? "\n" : "\n\n");
}
exit 0;
