#!/usr/bin/perl -w

# This script replaces the macros in an existing MapTool token file with
# the new XML generated from the d20srd.org spell pages.

use strict;
use File::Find ();
use DirHandle;
sub wanted;

# Where to put the resulting rptok files.
&rm_rf('tokens') if -d 'tokens';
mkdir('tokens');

my $file;
my $base;
my $dh = new DirHandle("../tokens/");
while ($file = $dh->read) {
    next unless $file =~ /\.rptok$/i;
    ($base = $file) =~ s/\.rptok$//i;
    next unless -e "$base.xml";
    print STDERR "Processing $file\n";

    # Temporary directory for extracting the existing rptok file.
    &rm_rf('tmp') if -d 'tmp';
    mkdir('tmp');
    chdir('tmp');

    system("unzip '../../tokens/$file' >/dev/null");
    open(ORIG_CONTENT, "< content.xml") or
	die "Can't open 'tmp/content.xml' for read; $file!?\n$!";
    open(NEW_CONTENT, "< ../$base.xml") or
	die "Can't open '$base.xml' for read!?\n$!";
    open(OUTPUT, "> content.new") or
	die "Can't create new 'tmp/content.new' for output!?\n$!";

    # Print every line up to -- but not including -- 'macroPropertiesMap'
    # This is because NEW_CONTENT contains the entire macroPropertiesMap
    # element.
    while (<ORIG_CONTENT>) {
	last if m#macroPropertiesMap#;
	print OUTPUT;
    }
    my $empty = m#macroPropertiesMap\s*/#;

    # Insert the newly generated XML content and close that file
    print OUTPUT <NEW_CONTENT>;
    close(NEW_CONTENT);

    # Skip all lines up to '/macroPropertiesMap'
    if (!$empty) {
	while (<ORIG_CONTENT>) {
	    last if m#/macroPropertiesMap#;
	}
    }
    # Print the rest of the file and close it.  Note that the closing
    # tag is not printed (it's part of NEW_CONTENT).
    print OUTPUT <ORIG_CONTENT>;
    close(ORIG_CONTENT);

    rename('content.new', 'content.xml');
    system("zip -r9 '../tokens/$base.rptok' * >/dev/null");
    chdir('..');
}
&rm_rf('tmp') if -d 'tmp';
exit 0;

# Traverse desired directories, deleting them and their contents.
sub rm_rf {
    no strict;
    File::Find::find({wanted => \&wanted}, @_);
}

sub wanted {
    -d $_ && rmdir($_) || unlink($_);
}
